@@ -126,6 +126,13 @@ bats <- function(y, use.box.cox=NULL, use.trend=NULL, use.damped.trend=NULL, sea
 	} else if(class(y) == "ts") {
 		seasonal.periods <- frequency(y)
 	}
+	if(all((seasonal.periods == 1))) {
+		seasonal.periods <- NULL	
+	}
+	if(!is.null(seasonal.periods)) {
+		seasonal.mask <- (seasonal.periods == 1)
+		seasonal.periods <- seasonal.periods[!seasonal.mask]
+	}
   y <- as.numeric(y)
 	best.aic <- NULL
 	if(is.null(use.box.cox)) {
